==> ilias-3.7.3_1.tbz: www/ilias/chat.php <==
<?php
/*
	+-----------------------------------------------------------------------------+
	| ILIAS open source                                                           |
	+-----------------------------------------------------------------------------+
	| Copyright (c) 1998-2006 ILIAS open source, University of Cologne            |
	|                                                                             |
	| This program is free software; you can redistribute it and/or               |
	| modify it under the terms of the GNU General Public License                 |
	| as published by the Free Software Foundation; either version 2              |
	| of the License, or (at your option) any later version.                      |
	|                                                                             |
	| This program is distributed in the hope that it will be useful,             |
	| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
	| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
	| GNU General Public License for more details.                                |
	|                                                                             |
	| You should have received a copy of the GNU General Public License           |
	| along with this program; if not, write to the Free Software                 |
	| Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
	+-----------------------------------------------------------------------------+
*/


/**
* Chat base script
*
* @author Stefan Meyer <smeyer@databay.de>
* @version $Id: chat.php,v 1.7 2006/08/28 06:43:02 rs Exp $
*
* @package ilias-chat
*/


require_once "include/inc.header.php";
include_once "chat/classes/class.ilObjChatGUI.php";

global $ilCtrl, $tpl;

$ilCtrl->setTargetScript("chat.php");
$ilCtrl->getCallStructure("ilobjchatgui");

$chat_gui =& new ilObjChatGUI('',(int) $_GET['ref_id'],true,false);
$ilCtrl->forwardCommand($chat_gui);
$tpl->show();
?>

==> ilias-3.9.6.tbz: www/ilias/chat.php <==
<?php
/*
	+-----------------------------------------------------------------------------+
	| ILIAS open source                                                           |
	+-----------------------------------------------------------------------------+
	| Copyright (c) 1998-2006 ILIAS open source, University of Cologne            |
	|                                                                             |
	| This program is free software; you can redistribute it and/or               |
	| modify it under the terms of the GNU General Public License                 |
	| as published by the Free Software Foundation; either version 2              |
	| of the License, or (at your option) any later version.                      |
	|                                                                             |
	| This program is distributed in the hope that it will be useful,             |
	| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
	| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
	| GNU General Public License for more details.                                |
	|                                                                             |
	| You should have received a copy of the GNU General Public License           |
	| along with this program; if not, write to the Free Software                 |
	| Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
	+-----------------------------------------------------------------------------+
*/


/**
* Chat base script
*
* @author Stefan Meyer <smeyer@databay.de>
* @version $Id: chat.php 15434 2007-11-27 09:02:01Z smeyer $
*
* @package ilias-chat
*/


require_once "./include/inc.header.php";
require_once "./Modules/Chat/classes/class.ilChatController.php";

global $ilAuth;

if(!$ilAuth->getAuth() or !$rbacsystem->checkAccess("read",(int) $_GET["ref_id"]))
{
	$_GET["cmd"] = "closeFrame";
}

$chat_controller =& new ilChatController((int) $_GET["ref_id"]);
$chat_controller->execute();

$tpl->show(false);

?>
